@@ -4,7 +4,7 @@
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2022 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 #ifndef __XMLSEC_GNUTLS_SYMBOLS_H__
 #define __XMLSEC_GNUTLS_SYMBOLS_H__
@@ -54,6 +54,9 @@ extern "C" {
  *
  * Crypto transforms ids
  *
+ * https://www.aleksey.com/xmlsec/xmldsig.html
+ * https://www.aleksey.com/xmlsec/xmlenc.html
+ *
  ********************************************************************/
 #define xmlSecTransformAes128CbcId              xmlSecGnuTLSTransformAes128CbcId
 #define xmlSecTransformAes192CbcId              xmlSecGnuTLSTransformAes192CbcId
@@ -78,7 +81,6 @@ extern "C" {
 #define xmlSecTransformHmacSha256Id             xmlSecGnuTLSTransformHmacSha256Id
 #define xmlSecTransformHmacSha384Id             xmlSecGnuTLSTransformHmacSha384Id
 #define xmlSecTransformHmacSha512Id             xmlSecGnuTLSTransformHmacSha512Id
-#define xmlSecTransformHmacRipemd160Id          xmlSecGnuTLSTransformHmacRipemd160Id
 #define xmlSecTransformHmacSha1Id               xmlSecGnuTLSTransformHmacSha1Id
 
 #define xmlSecTransformPbkdf2Id                 xmlSecGnuTLSTransformPbkdf2Id
@@ -101,6 +103,8 @@ extern "C" {
 #define xmlSecTransformSha3_384Id               xmlSecGnuTLSTransformSha3_384Id
 #define xmlSecTransformSha3_512Id               xmlSecGnuTLSTransformSha3_512Id
 
+#define xmlSecTransformGostR3411_94Id           xmlSecGnuTLSTransformGostR3411_94Id
+#define xmlSecTransformGost2001GostR3411_94Id   xmlSecGnuTLSTransformGost2001GostR3411_94Id
 
 /********************************************************************
  *
@@ -118,7 +122,6 @@ extern "C" {
 #define xmlSecCryptoAppKeysMngrCertLoadMemory   xmlSecGnuTLSAppKeysMngrCertLoadMemory
 #define xmlSecCryptoAppKeysMngrCrlLoad          xmlSecGnuTLSAppKeysMngrCrlLoad
 #define xmlSecCryptoAppKeysMngrCrlLoadMemory    xmlSecGnuTLSAppKeysMngrCrlLoadMemory
-#define xmlSecCryptoAppKeyLoad                  xmlSecGnuTLSAppKeyLoad
 #define xmlSecCryptoAppKeyLoadEx                xmlSecGnuTLSAppKeyLoadEx
 #define xmlSecCryptoAppPkcs12Load               xmlSecGnuTLSAppPkcs12Load
 #define xmlSecCryptoAppKeyCertLoad              xmlSecGnuTLSAppKeyCertLoad
